@@ -603,7 +603,7 @@ class ChainManager:
             self._reset_locs(from_node)
             self._reset_locs(to_node)
 
-    def pan_up(self, pan_node: ChainDict, up_step: int=0) -> None:
+    def pan_up(self, pan_node: ChainDict, up_step: int=0, top: bool=False) -> None:
         if not isinstance(pan_node, ChainDict):
             raise TypeError('`pan_node` must be `ChainDict`.')
         if not (isinstance(up_step, int) and up_step>=0):
@@ -613,6 +613,8 @@ class ChainManager:
         new_loc = pan_node_loc - up_step
         if new_loc < 0:
             new_loc = 0
+
+        if top: new_loc = 0
         
         change_nodes = sorted(filter(lambda x:int(x[self.loc_key])>=new_loc, self.get_siblings(pan_node)), key=lambda x:int(x[self.loc_key]), reverse=False)
         for i, node in enumerate(change_nodes):
@@ -620,7 +622,7 @@ class ChainManager:
         
         self.update_attr(pan_node, self.loc_key, str(new_loc))
     
-    def pan_down(self, pan_node: ChainDict, down_step: int=0):
+    def pan_down(self, pan_node: ChainDict, down_step: int=0, bottom: bool=False):
         if not isinstance(pan_node, ChainDict):
             raise TypeError('`pan_node` must be `ChainDict`.')
         if not (isinstance(down_step, int) and down_step>=0):
@@ -634,6 +636,8 @@ class ChainManager:
 
         if new_loc > max_loc:
             new_loc = max_loc
+
+        if bottom: new_loc = max_loc
         
         change_nodes = sorted(filter(lambda x:int(x[self.loc_key])<=new_loc, subling_nodes), key=lambda x:int(x[self.loc_key]), reverse=False)
         for i, node in enumerate(change_nodes):
